{ config, lib, pkgs, ... }:

{
  fileSystems = {
    "/" = {
      device = "/dev/disk/by-label/root";
      fsType = "btrfs";
    };
    "/boot" = {
      device = "/dev/disk/by-label/boot";
      fsType = "vfat";
    };
  };
  swapDevices = [
    {
      device = "/dev/disk/by-label/swap";
    }
  ];

  ptw = {
    programs = {
      mpv.enable = true;
      tmux.enable = true;
      zsh.enable = true;
      git.enable = true;
      gnome-terminal.enable = true;
      firefox.enable = true;
      xournalpp.enable = true;
      # TODO: Nextcloud client
    };
    services = {
      gnome.enable = true;
    };
    system = {
      i18n.enable = true;
      singleUser = "alexander";
      hostName = "mashu";
      wireless = true;
      primaryInterface = "wlp1s0";
      offloading.offload.enable = true;
    };
    hardware = {
      intel.enable = true;
      mobile.enable = true;
      surface.enable = true;
    };
  };
  
  boot = {
    kernelParams = [ "mem_sleep_default=deep" "kernel.nmi_watchdog=0" "vm.dirty_writeback_centisecs=1500" ];
    extraModprobeConfig = ''
      	options i915 enable_fbc=1 enable_rc6=1 modeset=1
      	options snd_hda_intel power_save=1
       	options snd_ac97_codec power_save=1
      	options iwlwifi power_save=Y
        options iwldvm force_cam=N
      '';
    initrd = {
      availableKernelModules = [ "xhci_pci" "nvme" "usbhid" ];
      kernelModules = [ "kvm-intel" ];
    };
  };
}
